@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024  copilot-chat maintainers
 
 ;; Author: cedric.chepied <cedric.chepied@gmail.com>
-;; Package-Version: 20251112.1222
-;; Package-Revision: 1bded1dbe4e8
+;; Package-Version: 20260105.858
+;; Package-Revision: 9dd4b0c72e5e
 ;; URL: https://github.com/chep/copilot-chat.el
 ;; Package-Requires: ((emacs "29.1") (aio "1.0") (request "0.3.2") (transient "0.8.3") (polymode "0.2.2") (org "9.4.6") (markdown-mode "2.6") (shell-maker "0.76.2") (mcp "0.1.0"))
 ;; Keywords: convenience, tools
@@ -70,14 +70,13 @@
   :group 'copilot-chat)
 
 (defcustom copilot-chat-backend 'curl
-  "Copilot chat backend.  Can be `curl` or `request`."
+  "Copilot chat backend.  Can be `curl` or a custom on."
   :type '(choice (const :tag "curl" curl) (const :tag "request" request))
   :set
   (lambda (symbol value)
     (set-default-toplevel-value symbol value)
     (pcase value
-      (`curl (require 'copilot-chat-curl))
-      (`request (require 'copilot-chat-request))))
+      (`curl (require 'copilot-chat-curl))))
   :group 'copilot-chat)
 
 (provide 'copilot-chat)
